@@ -1,4 +1,4 @@
-# Copyright Jiaqi (Hutao of Emberfire)
+# Copyright Jiaqi Liu
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ from wilhelm_python_sdk.vocabulary_parser import GERMAN
 from wilhelm_python_sdk.vocabulary_parser import get_attributes
 from wilhelm_python_sdk.vocabulary_parser import get_definitions
 from wilhelm_python_sdk.vocabulary_parser import get_inferred_declension_links
+from wilhelm_python_sdk.vocabulary_parser import get_inferred_links
 from wilhelm_python_sdk.vocabulary_parser import \
     get_inferred_tokenization_links
 
@@ -98,6 +99,33 @@ class TestLoader(unittest.TestCase):
             get_attributes(yaml.safe_load(HUT_YAML), GERMAN, "name"),
         )
 
+    def test_get_inferred_links_on_unrelated_terms(self):
+        vocabulary = yaml.safe_load("""
+            vocabulary:
+              - term: der Beruf
+                definition: job
+                declension:
+                  - ["",         singular,          plural ]
+                  - [nominative, Beruf,             Berufe ]
+                  - [genitive,   "Berufes, Berufs", Berufe ]
+                  - [dative,     Beruf,             Berufen]
+                  - [accusative, Beruf,             Berufe ]
+              - term: der Qualitätswein
+                definition: The vintage wine
+                declension:
+                  - ["",         singular,                          plural         ]
+                  - [nominative, Qualitätswein,                     Qualitätsweine ]
+                  - [genitive,   "Qualitätsweines, Qualitätsweins", Qualitätsweine ]
+                  - [dative,     Qualitätswein,                     Qualitätsweinen]
+                  - [accusative, Qualitätswein,                     Qualitätsweine ]
+        """)["vocabulary"]
+        label_key = "name"
+
+        self.assertEqual(
+            [],
+            get_inferred_links(vocabulary, label_key)
+        )
+
     def test_get_inferred_declension_links(self):
         DER_REIS = """
             term: der Reis
